@@ -26,7 +26,7 @@
 #' mtcars_tbl <- sdf_copy_to(sc, mtcars, name = "mtcars_tbl", overwrite = TRUE)
 #'
 #' partitions <- mtcars_tbl %>%
-#'   sdf_partition(training = 0.7, test = 0.3, seed = 1111)
+#'   sdf_random_split(training = 0.7, test = 0.3, seed = 1111)
 #'
 #' mtcars_training <- partitions$training
 #' mtcars_test <- partitions$test
@@ -253,3 +253,7 @@ new_ml_multiclass_classification_evaluator <- function(jobj) {
 new_ml_regression_evaluator <- function(jobj) {
   new_ml_evaluator(jobj, class = "ml_regression_evaluator")
 }
+
+new_ml_clustering_evaluator <- function(jobj) {
+  new_ml_evaluator(jobj, class = "ml_clustering_evaluator")
+}
