@@ -11,9 +11,12 @@
 #' @export
 ft_elementwise_product <- function(x, input_col = NULL, output_col = NULL, scaling_vec = NULL,
   uid = random_string("elementwise_product_"), ...) {
+  check_dots_used()
   UseMethod("ft_elementwise_product")
 }
 
+ml_elementwise_product <- ft_elementwise_product
+
 #' @export
 ft_elementwise_product.spark_connection <- function(x, input_col = NULL, output_col = NULL, scaling_vec = NULL,
                                                     uid = random_string("elementwise_product_"), ...) {
@@ -26,9 +29,9 @@ ft_elementwise_product.spark_connection <- function(x, input_col = NULL, output_
     uid = uid
   ) %>%
     c(rlang::dots_list(...)) %>%
-    ml_validator_elementwise_product()
+    validator_ml_elementwise_product()
 
-  jobj <- ml_new_transformer(
+  jobj <- spark_pipeline_stage(
     x, "org.apache.spark.ml.feature.ElementwiseProduct",
     input_col = .args[["input_col"]], output_col = .args[["output_col"]], uid = .args[["uid"]])
   if (!is.null(.args[["scaling_vec"]]))
@@ -66,11 +69,11 @@ ft_elementwise_product.tbl_spark <- function(x, input_col = NULL, output_col = N
 }
 
 new_ml_elementwise_product <- function(jobj) {
-  new_ml_transformer(jobj, subclass = "ml_elementwise_product")
+  new_ml_transformer(jobj, class = "ml_elementwise_product")
 }
 
 # ElementwiseProduct
-ml_validator_elementwise_product <- function(.args) {
+validator_ml_elementwise_product <- function(.args) {
   .args <- validate_args_transformer(.args)
   .args[["scaling_vec"]] <- cast_nullable_double_list(.args[["scaling_vec"]])
   .args
