@@ -2,97 +2,6 @@ is.installed <- function(package) {
   is.element(package, installed.packages()[,1])
 }
 
-get_java <- function(throws = FALSE) {
-  java_home <- Sys.getenv("JAVA_HOME", unset = NA)
-  if (!is.na(java_home)) {
-    java <- file.path(java_home, "bin", "java")
-    if (identical(.Platform$OS.type, "windows")) {
-      java <- paste0(java, ".exe")
-    }
-    if (!file.exists(java)) {
-      if (throws) {
-        stop("Java is required to connect to Spark. ",
-             "JAVA_HOME is set to '",
-             java_home,
-             "' but does not point to a valid version. ",
-             "Please fix JAVA_HOME or reinstall from: ",
-             java_install_url())
-      }
-      java <- ""
-    }
-  } else
-    java <- Sys.which("java")
-  java
-}
-
-is_java_available <- function() {
-  nzchar(get_java())
-}
-
-validate_java_version_line <- function(master, version) {
-  if (length(version) < 1)
-    stop("Java version not detected. Please download and install Java from ",
-         java_install_url())
-
-  # find line with version info
-  versionLine <- version[grepl("version", version)]
-  if (length(versionLine) != 1)
-    stop("Java version detected but couldn't parse version from ", paste(version, collapse = " - "))
-
-  # transform to usable R version string
-  splat <- strsplit(versionLine, "\\s+", perl = TRUE)[[1]]
-
-  splatVersion <- splat[grepl("9|[0-9]+\\.[0-9]+\\.[0-9]+", splat)]
-  if (length(splatVersion) != 1)
-    stop("Java version detected but couldn't parse version from: ", versionLine)
-
-  parsedVersion <- regex_replace(
-    splatVersion,
-    "^\"|\"$" = "",
-    "_" = ".",
-    "[^0-9.]+" = ""
-  )
-
-  if (!is.character(parsedVersion) || nchar(parsedVersion) < 1)
-    stop("Java version detected but couldn't parse version from: ", versionLine)
-
-  # ensure Java 1.7 or higher
-  if (compareVersion(parsedVersion, "1.7") < 0)
-    stop("Java version", parsedVersion, " detected but 1.7+ is required. Please download and install Java from ",
-         java_install_url())
-
-  if (compareVersion(parsedVersion, "1.9") >= 0 && spark_master_is_local(master)  && !getOption("sparklyr.java9", FALSE)) {
-    stop(
-      "Java 9 is currently unsupported in Spark distributions unless you manually install Hadoop 2.8 ",
-      "and manually configure Spark. Please consider uninstalling Java 9 and reinstalling Java 8. ",
-      "To override this failure set 'options(sparklyr.java9 = TRUE)'.")
-  }
-}
-
-validate_java_version <- function(master, spark_home) {
-  # if someone sets SPARK_HOME and we are not in local more, assume Java
-  # is available since some systems.
-  # (e.g. CDH) use versions of java not discoverable through JAVA_HOME.
-  if (!spark_master_is_local(master) && !is.null(spark_home) && nchar(spark_home) > 0)
-    return(TRUE)
-
-  # find the active java executable
-  java <- get_java(throws = TRUE)
-  if (!nzchar(java))
-    stop("Java is required to connect to Spark. Please download and install Java from ",
-         java_install_url())
-
-  # query its version
-  version <- system2(java, "-version", stderr = TRUE, stdout = TRUE)
-  validate_java_version_line(master, version)
-
-  TRUE
-}
-
-java_install_url <- function() {
-  "https://www.java.com/en/"
-}
-
 utils_starts_with <- function(lhs, rhs) {
   if (nchar(lhs) < nchar(rhs))
     return(FALSE)
@@ -120,10 +29,6 @@ random_string <- function(prefix = "table") {
   basename(tempfile(prefix))
 }
 
-is_spark_v2 <- function(scon) {
-  spark_version(scon) >= "2.0.0"
-}
-
 printf <- function(fmt, ...) {
   cat(sprintf(fmt, ...))
 }
@@ -156,6 +61,14 @@ regex_replace <- function(string, ...) {
 }
 
 spark_sanitize_names <- function(names, config) {
+  # Spark 1.6.X has a number of issues with '.'s in column names, e.g.
+  #
+  #    https://issues.apache.org/jira/browse/SPARK-5632
+  #    https://issues.apache.org/jira/browse/SPARK-13455
+  #
+  # Many of these issues are marked as resolved, but it appears this is
+  # a common regression in Spark and the handling is not uniform across
+  # the Spark API.
 
   # sanitize names by default, but opt out with global option
   if (!isTRUE(spark_config_value(config, "sparklyr.sanitize.column.names", TRUE)))
@@ -322,3 +235,14 @@ resolve_fn <- function(fn, ...) {
 is.tbl_spark <- function(x) {
   inherits(x, "tbl_spark")
 }
+
+`%<-%` <- function(x, value) {
+  dest <- as.character(as.list(substitute(x))[-1])
+  if (length(dest) != length(value)) stop("Assignment must contain same number of elements")
+
+  for (i in seq_along(dest)) {
+    assign(dest[i], value[i], envir = sys.frame(which =sys.parent(n = 1)))
+  }
+
+  invisible(NULL)
+}
