@@ -3,20 +3,25 @@ package sparklyr
 class Sources {
   def sources: String = """
 arrow_write_record_batch <- function(df) {
+  record_batch <- get("record_batch", envir = as.environment(asNamespace("arrow")))
+
   if (packageVersion("arrow") < "0.12") {
-    record_batch <- get("record_batch", envir = as.environment(asNamespace("arrow")))
     write_record_batch <- get("write_record_batch", envir = as.environment(asNamespace("arrow")))
 
     record <- record_batch(df)
     write_record_batch(record, raw())
   }
-  else {
-    record_batch <- get("record_batch", envir = as.environment(asNamespace("arrow")))
+  if (packageVersion("arrow") <= "0.13") {
     record <- record_batch(df)
 
     write_arrow <- get("write_arrow", envir = as.environment(asNamespace("arrow")))
     write_arrow(record, raw())
+  }
+  else {
+    record <- record_batch(!!!df)
 
+    write_arrow <- get("write_arrow", envir = as.environment(asNamespace("arrow")))
+    write_arrow(record, raw())
   }
 }
 
@@ -43,7 +48,10 @@ arrow_read_record_batch <- function(reader) {
 }
 
 arrow_as_tibble <- function(record) {
-  as_tibble <- get("as_tibble", envir = as.environment(asNamespace("arrow")))
+  if (packageVersion("arrow") <= "0.13")
+    as_tibble <- get("as_tibble", envir = as.environment(asNamespace("arrow")))
+  else
+    as_tibble <- get("as.data.frame", envir = as.environment(asNamespace("arrow")))
 
   as_tibble(record)
 }
@@ -1153,7 +1161,10 @@ spark_worker_init_packages <- function(sc, context) {
   else {
     spark_env <- worker_invoke_static(sc, "org.apache.spark.SparkEnv", "get")
     spark_libpaths <- worker_invoke(worker_invoke(spark_env, "conf"), "get", "spark.r.libpaths", NULL)
-    if (!is.null(spark_libpaths)) .libPaths(spark_libpaths)
+    if (!is.null(spark_libpaths)) {
+      spark_libpaths <- unlist(strsplit(spark_libpaths, split = ","))
+      .libPaths(spark_libpaths)
+    }
   }
 }
 
